@@ -3,15 +3,14 @@
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef COMMON_CONTROL_H
-#define COMMON_CONTROL_H
+#pragma once
 
 #include <kscreen/output.h>
 #include <kscreen/types.h>
 
+#include <QList>
 #include <QObject>
 #include <QVariantMap>
-#include <QVector>
 
 class KDirWatch;
 
@@ -19,13 +18,6 @@ class Control : public QObject
 {
     Q_OBJECT
 public:
-    enum class OutputRetention {
-        Undefined = -1,
-        Global = 0,
-        Individual = 1,
-    };
-    Q_ENUM(OutputRetention)
-
     explicit Control(QObject *parent = nullptr);
 
     ~Control() override = default;
@@ -45,8 +37,6 @@ protected:
     const QVariantMap &constInfo() const;
     KDirWatch *watcher() const;
 
-    static OutputRetention convertVariantToOutputRetention(QVariant variant);
-
 private:
     static QString s_dirName;
     QVariantMap m_info;
@@ -61,20 +51,9 @@ class ControlConfig : public Control
 public:
     explicit ControlConfig(KScreen::ConfigPtr config, QObject *parent = nullptr);
 
-    OutputRetention getOutputRetention(const KScreen::OutputPtr &output) const;
-    OutputRetention getOutputRetention(const QString &outputId, const QString &outputName) const;
-    void setOutputRetention(const KScreen::OutputPtr &output, OutputRetention value);
-    void setOutputRetention(const QString &outputId, const QString &outputName, OutputRetention value);
-
     qreal getScale(const KScreen::OutputPtr &output) const;
     void setScale(const KScreen::OutputPtr &output, qreal value);
 
-    bool getAutoRotate(const KScreen::OutputPtr &output) const;
-    void setAutoRotate(const KScreen::OutputPtr &output, bool value);
-
-    bool getAutoRotateOnlyInTabletMode(const KScreen::OutputPtr &output) const;
-    void setAutoRotateOnlyInTabletMode(const KScreen::OutputPtr &output, bool value);
-
     KScreen::OutputPtr getReplicationSource(const KScreen::OutputPtr &output) const;
     void setReplicationSource(const KScreen::OutputPtr &output, const KScreen::OutputPtr &source);
 
@@ -100,13 +79,13 @@ private:
     ControlOutput *getOutputControl(const QString &outputId, const QString &outputName) const;
 
     template<typename T, typename F>
-    T get(const KScreen::OutputPtr &output, const QString &name, F globalRetentionFunc, T defaultValue) const;
+    T get(const KScreen::OutputPtr &output, F globalRetentionFunc, T defaultValue) const;
     template<typename T, typename F, typename V>
     void set(const KScreen::OutputPtr &output, const QString &name, F globalRetentionFunc, V value);
 
     KScreen::ConfigPtr m_config;
     QStringList m_duplicateOutputIds;
-    QVector<ControlOutput *> m_outputsControls;
+    QList<ControlOutput *> m_outputsControls;
 };
 
 class ControlOutput : public Control
@@ -123,12 +102,6 @@ public:
     qreal getScale() const;
     void setScale(qreal value);
 
-    bool getAutoRotate() const;
-    void setAutoRotate(bool value);
-
-    bool getAutoRotateOnlyInTabletMode() const;
-    void setAutoRotateOnlyInTabletMode(bool value);
-
     uint32_t overscan() const;
     void setOverscan(uint32_t value);
 
@@ -144,5 +117,3 @@ public:
 private:
     KScreen::OutputPtr m_output;
 };
-
-#endif
