@@ -45,17 +45,9 @@ public:
         m_config = (m_previousConfig ? m_previousConfig : m_initialConfig)->clone();
     }
 
-    int retention() const;
-    void setRetention(int retention);
-
     KScreen::OutputPtr replicationSource(const KScreen::OutputPtr &output) const;
     void setReplicationSource(KScreen::OutputPtr &output, const KScreen::OutputPtr &source);
 
-    bool autoRotate(const KScreen::OutputPtr &output) const;
-    void setAutoRotate(KScreen::OutputPtr &output, bool autoRotate);
-    bool autoRotateOnlyInTabletMode(const KScreen::OutputPtr &output) const;
-    void setAutoRotateOnlyInTabletMode(KScreen::OutputPtr &output, bool value);
-
     uint32_t overscan(const KScreen::OutputPtr &output) const;
     void setOverscan(const KScreen::OutputPtr &output, uint32_t value);
 
@@ -75,13 +67,11 @@ Q_SIGNALS:
     void changed();
     void screenNormalizationUpdate(bool normalized);
     void needsSaveChecked(bool need);
-    void retentionChanged();
     void outputConnect(bool connected);
 
 private:
     void checkScreenNormalization();
     QSize screenSize() const;
-    Control::OutputRetention getRetention() const;
     void outputPrioritiesChanged();
     void initOutput(const KScreen::OutputPtr &output);
     /**
@@ -100,6 +90,5 @@ private:
 
     std::unique_ptr<ControlConfig> m_control;
     std::unique_ptr<ControlConfig> m_initialControl;
-    Control::OutputRetention m_initialRetention = Control::OutputRetention::Undefined;
     QSize m_lastNormalizedScreenSize;
 };
